# G2S Package description

This package containe the interfaces for comunicating with the G2S server. G2S is a flexible MPS (Multiple Point Statistics) framework that provide QS (Quantile Sampling) and NDS (Narrow Distribution Selection).

For more infromation please visite [G2S website](https://gaia-unil.github.io/G2S/)